@@ -111,14 +111,14 @@ def session_state_str_dict():
     interface = {"user": None, "session_state": None}
     extra = {"user": repr(st.session_state["user"])  if "user" in st.session_state else None,
             "session_state": {k: f"{v}" for k, v in st.session_state.to_dict().items()}}
-    merged = interface | extra
+    merged = {**interface, **extra}
     return merged
 
 def bind_log(extras = {}) -> Logger:
     """
     Bind the logger to the session state dictionary
     """
-    merged = session_state_str_dict() | extras
+    merged = {**session_state_str_dict(), **extras}
     log = _LOGGER.bind(**merged)
     return log
 
