@@ -19,7 +19,7 @@ default_bucket = st.secrets["firebase"]["storageBucket"]
 
 # Create API client.
 credentials = service_account.Credentials.from_service_account_info(
-    st.secrets["gcp_service_account"]
+    dict(st.secrets["gcp_service_account"])
 )
 client = storage.Client(credentials=credentials)
 
